@@ -20,11 +20,10 @@ connection.get_db_by_table = get_db_by_table
 from sqlbean.shortcut import Model
 
 class User(Model):
-    class Meta:
-        pk = "UserId"
+    pass
 
 for i in User.where():
-    print i.UserId
+    print i.id
 
 
 
