@@ -2,7 +2,7 @@
 from sqlbean.db.query import Query, escape
 from sqlbean.db.mc_connection import mc
 from marshal import dumps, loads
-from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create,save
+from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create, save, get, __eq__
 from array import array
 from datetime import datetime
 
@@ -11,10 +11,10 @@ def model_dumps(self):
     for i in self._fields:
         v = self.__dict__.get(i, None)
         if type(v) is datetime:
-            v = v.strftime("%Y-%m-%d %H:%M:%S")             
+            v = v.strftime("%Y-%m-%d %H:%M:%S")
         value.append(v)
     value = dumps(tuple(value))
-    return value 
+    return value
 
 class McModel(object):
     @classmethod
@@ -28,6 +28,7 @@ class McModel(object):
 
     debug = False
     get_or_create = get_or_create
+    __eq__ = __eq__
     def __init__(self, *args, **kwargs):
         'Allows setting of fields using kwargs'
         self.__dict__[self.Meta.pk] = None
@@ -74,7 +75,7 @@ class McModel(object):
     def mc_get_list(cls, id_list):
         id_list = tuple(id_list)
         mc_key = cls.Meta.mc_key
-        result = mc.get_multi_marshal([mc_key%i for i in id_list],cls._loads)
+        result = mc.get_multi_marshal([mc_key%i for i in id_list], cls._loads)
         r = []
         for i in id_list:
             t = result.get(mc_key%i)
@@ -96,7 +97,7 @@ class McModel(object):
 
     def mc_set(self):
         key = self.Meta.mc_key%self.id
-        mc.set_marshal(key,self,dumps=model_dumps)
+        mc.set_marshal(key, self, dumps=model_dumps)
 
     def __setattr__(self, name, value):
         'Records when fields have changed'
@@ -178,6 +179,8 @@ class McModel(object):
                         if callable(v):
                             v = getattr(i, k)()
                         setattr(self, k, v)
+
+
     @classmethod
     def raw_sql(cls, query, *args):
         result = Query.raw_sql(query, args, cls.db)
@@ -214,19 +217,7 @@ class McModel(object):
             conditions=kwargs
         )
 
-    @classmethod
-    def get(cls, __obj_pk=None, **kwargs):
-        if __obj_pk is not None:
-            kwargs = {
-                cls.Meta.pk: __obj_pk
-            }
-        q = Query(model=cls, conditions=kwargs)
-        q = q.execute_query()
-        q = q.fetchone()
-        if q:
-            obj = cls(*q)
-            obj.__dict__['_new_record'] = False
-            return obj
+    get = get
 
     @classmethod
     def count(cls, *args, **kwargs):
@@ -283,9 +274,22 @@ class McModel(object):
         ins.save()
 
         return ins
+
     @classmethod
-    def mc_bind(cls,xxx_list,property,key="id"):
-           d = dict( (getattr(i,key),i) for i in xxx_list  )
-           r = cls.mc_get_multi(d)
-           for k,v in d.iteritems():
-                 v.__dict__[property] = r.get(k)
+    def mc_bind(cls, xxx_list, property, key="id"):
+        d = []
+        e = []
+        for i in xxx_list:
+            k = getattr(i, key)
+            if k:
+                d.append(k)
+                e.append((k, i))
+            else:
+                i.__dict__[property] = None
+
+        r = cls.mc_get_multi(set(d))
+        for k, v in e:
+            v.__dict__[property] = r.get(k)
+
+
+
