@@ -1,6 +1,31 @@
-from sqlbean.db.query import escape
+from sqlbean.db.query import escape, Query
 from sqlbean.db.connection import get_db_by_table
 
+
+def __eq__(self, other):
+    sid = self.id
+    oid = other.id
+    if sid is not None and oid is not None:
+        return sid == oid
+    return False
+
+@classmethod
+def get(cls, __obj_pk=None, **kwargs):
+    if __obj_pk is None:
+        if not kwargs:
+            return
+    else:
+        kwargs = {
+            cls.Meta.pk: __obj_pk
+        }
+    q = Query(model=cls, conditions=kwargs)
+    q = q.execute_query()
+    q = q.fetchone()
+    if q:
+        obj = cls(*q)
+        obj.__dict__['_new_record'] = False
+        return obj
+
 def save(self):
     if self._new_record:
         self._set_default()
